@@ -56,6 +56,10 @@
  * #GtkSourceCompletion machinery, you don't need to worry about this.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <gtksourceview/gtksourcecompletioninfo.h>
 #include "gtksourceview-i18n.h"
 
@@ -67,8 +71,6 @@ struct _GtkSourceCompletionInfoPrivate
 	gulong focus_out_event_handler;
 
 	gint xoffset;
-
-	guint transient_set : 1;
 };
 
 /* Signals */
@@ -242,8 +244,6 @@ set_attached_to (GtkSourceCompletionInfo *info,
 					  "focus-out-event",
 					  G_CALLBACK (focus_out_event_cb),
 					  info);
-
-	info->priv->transient_set = FALSE;
 }
 
 static void
@@ -293,23 +293,8 @@ gtk_source_completion_info_dispose (GObject *object)
 static void
 gtk_source_completion_info_show (GtkWidget *widget)
 {
-	GtkSourceCompletionInfo *info = GTK_SOURCE_COMPLETION_INFO (widget);
-
 	/* First emit BEFORE_SHOW and then chain up */
-	g_signal_emit (info, signals[BEFORE_SHOW], 0);
-
-	if (info->priv->attached_to != NULL && !info->priv->transient_set)
-	{
-		GtkWidget *toplevel;
-
-		toplevel = gtk_widget_get_toplevel (GTK_WIDGET (info->priv->attached_to));
-		if (gtk_widget_is_toplevel (toplevel))
-		{
-			gtk_window_set_transient_for (GTK_WINDOW (info),
-						      GTK_WINDOW (toplevel));
-			info->priv->transient_set = TRUE;
-		}
-	}
+	g_signal_emit (widget, signals[BEFORE_SHOW], 0);
 
 	GTK_WIDGET_CLASS (gtk_source_completion_info_parent_class)->show (widget);
 }
