@@ -19,6 +19,10 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "gtksourcegutter.h"
 #include "gtksourcegutter-private.h"
 #include "gtksourceview.h"
@@ -970,8 +974,9 @@ apply_style (GtkSourceGutter *gutter,
 	 * are not set by gtk.
 	 */
 	gtk_style_context_add_class (style_context, class);
+
 	gtk_style_context_get_color (style_context,
-	                             gtk_style_context_get_state (style_context),
+	                             gtk_widget_get_state_flags (GTK_WIDGET (view)),
 	                             &fg_color);
 
 	gdk_cairo_set_source_rgba (cr, &fg_color);
@@ -1098,18 +1103,7 @@ draw_cells (GtkSourceGutter *gutter,
 
 		if (!gtk_text_iter_ends_line (&end))
 		{
-			/*
-			 * It turns out that gtk_text_iter_forward_to_line_end
-			 * is slower than jumping to the next line in the
-			 * btree index and then moving backwards a character.
-			 * We don't really care that we might be after the
-			 * newline breaking characters, since those are part
-			 * of the same line (rather than the next line).
-			 */
-			if (gtk_text_iter_forward_line (&end))
-			{
-				gtk_text_iter_backward_char (&end);
-			}
+			gtk_text_iter_forward_to_line_end (&end);
 		}
 
 		/* Possible improvement: if buffer and window coords have the
@@ -1461,9 +1455,9 @@ redraw_for_window (GtkSourceGutter *gutter,
                    gint             y)
 {
 	Renderer *at_x = NULL;
-	gint start = 0;
 	GList *item;
 	gboolean redraw;
+	gint start;
 
 	if (event->window != get_window (gutter) && act_on_window)
 	{
