@@ -19,6 +19,10 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "gtksourcegutterrenderermarks.h"
 #include "gtksourceview.h"
 #include "gtksourcebuffer.h"
@@ -413,7 +417,7 @@ gtk_source_gutter_renderer_marks_init (GtkSourceGutterRendererMarks *self)
 }
 
 GtkSourceGutterRenderer *
-gtk_source_gutter_renderer_marks_new ()
+gtk_source_gutter_renderer_marks_new (void)
 {
 	return g_object_new (GTK_SOURCE_TYPE_GUTTER_RENDERER_MARKS, NULL);
 }
