@@ -19,6 +19,10 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "gtksourcestylescheme.h"
 #include "gtksourcestyleschememanager.h"
 #include "gtksourcestyle-private.h"
@@ -674,11 +678,16 @@ get_cursors_css_style (GtkSourceStyleScheme *scheme,
 
 		context = gtk_widget_get_style_context (widget);
 
+		gtk_style_context_save (context);
+		gtk_style_context_set_state (context, GTK_STATE_FLAG_NORMAL);
+
 		gtk_style_context_get (context,
-				       GTK_STATE_FLAG_NORMAL,
+				       gtk_style_context_get_state (context),
 				       "background-color", &rgba,
 				       NULL);
 
+		gtk_style_context_restore (context);
+
 		/* shade the secondary cursor */
 		secondary_color.red = rgba->red * 0.5;
 		secondary_color.green = rgba->green * 0.5;
@@ -745,23 +754,22 @@ get_css_provider_cursors (GtkSourceStyleScheme *scheme,
 /**
  * _gtk_source_style_scheme_apply:
  * @scheme:: a #GtkSourceStyleScheme.
- * @widget: a #GtkWidget to apply styles to.
+ * @view: a #GtkSourceView to apply styles to.
  *
- * Sets text colors from @scheme in the @widget.
+ * Sets style colors from @scheme to the @view.
  *
  * Since: 2.0
  */
 void
 _gtk_source_style_scheme_apply (GtkSourceStyleScheme *scheme,
-				GtkWidget            *widget)
+				GtkSourceView        *view)
 {
 	GtkStyleContext *context;
 
 	g_return_if_fail (GTK_SOURCE_IS_STYLE_SCHEME (scheme));
-	g_return_if_fail (GTK_IS_WIDGET (widget));
+	g_return_if_fail (GTK_SOURCE_IS_VIEW (view));
 
-	/* we need to translate some of the style scheme properties in a CSS override */
-	context = gtk_widget_get_style_context (GTK_WIDGET (widget));
+	context = gtk_widget_get_style_context (GTK_WIDGET (view));
 	gtk_style_context_add_provider (context,
 	                                GTK_STYLE_PROVIDER (scheme->priv->css_provider),
 	                                GTK_SOURCE_STYLE_PROVIDER_PRIORITY);
@@ -776,7 +784,8 @@ _gtk_source_style_scheme_apply (GtkSourceStyleScheme *scheme,
 	 */
 	if (scheme->priv->css_provider_cursors == NULL)
 	{
-		scheme->priv->css_provider_cursors = get_css_provider_cursors (scheme, widget);
+		scheme->priv->css_provider_cursors = get_css_provider_cursors (scheme,
+									       GTK_WIDGET (view));
 	}
 
 	if (scheme->priv->css_provider_cursors != NULL)
@@ -794,22 +803,22 @@ _gtk_source_style_scheme_apply (GtkSourceStyleScheme *scheme,
 /**
  * _gtk_source_style_scheme_unapply:
  * @scheme: (allow-none): a #GtkSourceStyleScheme or %NULL.
- * @widget: a #GtkWidget to unapply styles to.
+ * @view: a #GtkSourceView to unapply styles to.
  *
- * Removes the style from @scheme in the @widget.
+ * Removes the styles from @scheme in the @view.
  *
  * Since: 3.0
  */
 void
 _gtk_source_style_scheme_unapply (GtkSourceStyleScheme *scheme,
-                                  GtkWidget            *widget)
+				  GtkSourceView        *view)
 {
 	GtkStyleContext *context;
 
 	g_return_if_fail (GTK_SOURCE_IS_STYLE_SCHEME (scheme));
-	g_return_if_fail (GTK_IS_WIDGET (widget));
+	g_return_if_fail (GTK_SOURCE_IS_VIEW (view));
 
-	context = gtk_widget_get_style_context (GTK_WIDGET (widget));
+	context = gtk_widget_get_style_context (GTK_WIDGET (view));
 	gtk_style_context_remove_provider (context,
 	                                   GTK_STYLE_PROVIDER (scheme->priv->css_provider));
 
@@ -908,10 +917,10 @@ generate_css_style (GtkSourceStyleScheme *scheme)
 	style = gtk_source_style_scheme_get_style (scheme, STYLE_LINE_NUMBERS);
 	if (style != NULL)
 	{
-		append_css_style (final_style, style, "border.top");
-		append_css_style (final_style, style, "border.right");
-		append_css_style (final_style, style, "border.bottom");
-		append_css_style (final_style, style, "border.left");
+		append_css_style (final_style, style, ".top");
+		append_css_style (final_style, style, ".right");
+		append_css_style (final_style, style, ".bottom");
+		append_css_style (final_style, style, ".left");
 
 		/* For the corners if the top or bottom gutter is also
 		 * displayed.
